Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.kernel.org/pub/scm/git/git.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJohannes Schindelin <johannes.schindelin@gmx.de>2020-11-19 02:44:38 +0300
committerJunio C Hamano <gitster@pobox.com>2020-11-20 02:44:18 +0300
commit5902f5f4608c1857fc04dcae2a0ce6beea31c8f8 (patch)
tree9a56000f293ef84871a419a00bb7a3abdcda6706 /t/t6422-merge-rename-corner-cases.sh
parent1f53df54eba378eee544b47f7c9e7f5fc32873e1 (diff)
t6[4-9]*: adjust the references to the default branch name "main"
This trick was performed via $ (cd t && sed -i -e 's/master/main/g' -e 's/MASTER/MAIN/g' \ -e 's/Master/Main/g' -- t6[4-9]*.sh) This allows us to define `GIT_TEST_DEFAULT_INITIAL_BRANCH_NAME=main` for those tests. Signed-off-by: Johannes Schindelin <johannes.schindelin@gmx.de> Signed-off-by: Junio C Hamano <gitster@pobox.com>
Diffstat (limited to 't/t6422-merge-rename-corner-cases.sh')
-rwxr-xr-xt/t6422-merge-rename-corner-cases.sh14
1 files changed, 7 insertions, 7 deletions
diff --git a/t/t6422-merge-rename-corner-cases.sh b/t/t6422-merge-rename-corner-cases.sh
index 9fb4e72ca3..bf4ce3c63d 100755
--- a/t/t6422-merge-rename-corner-cases.sh
+++ b/t/t6422-merge-rename-corner-cases.sh
@@ -3,7 +3,7 @@
test_description="recursive merge corner cases w/ renames but not criss-crosses"
# t6036 has corner cases that involve both criss-cross merges and renames
-GIT_TEST_DEFAULT_INITIAL_BRANCH_NAME=master
+GIT_TEST_DEFAULT_INITIAL_BRANCH_NAME=main
export GIT_TEST_DEFAULT_INITIAL_BRANCH_NAME
. ./test-lib.sh
@@ -1133,7 +1133,7 @@ test_conflicts_with_adds_and_renames() {
# Setup:
# L
# / \
- # master ?
+ # main ?
# \ /
# R
#
@@ -1263,7 +1263,7 @@ test_conflicts_with_adds_and_renames() {
:2:three \
:3:three &&
git rev-parse >expected \
- master:irrelevant_file \
+ main:irrelevant_file \
file_v2 \
file_v4 &&
test_cmp expected actual &&
@@ -1293,12 +1293,12 @@ test_conflicts_with_adds_and_renames add add
# Setup:
# L
# / \
-# master ?
+# main ?
# \ /
# R
#
# Where:
# master has two files, named 'one' and 'two'.
# branches L and R both modify 'one', in conflicting ways.
# branches L and R both modify 'two', in conflicting ways.
# branch L also renames 'one' to 'three'.
@@ -1379,7 +1379,7 @@ test_expect_success 'check nested conflicts from rename/rename(2to1)' '
test_line_count = 1 out &&
# Compare :2:three to expected values
- git cat-file -p master:one >base &&
+ git cat-file -p main:one >base &&
git cat-file -p L:three >ours &&
git cat-file -p R:one >theirs &&
test_must_fail git merge-file \
@@ -1390,7 +1390,7 @@ test_expect_success 'check nested conflicts from rename/rename(2to1)' '
test_cmp expect L-three &&
# Compare :2:three to expected values
- git cat-file -p master:two >base &&
+ git cat-file -p main:two >base &&
git cat-file -p L:two >ours &&
git cat-file -p R:three >theirs &&
test_must_fail git merge-file \
@@ -1293,12 +1293,12 @@ test_conflicts_with_adds_and_renames add add
#
# Where:
-# master has two files, named 'one' and 'two'.
+# main has two files, named 'one' and 'two'.
# branches L and R both modify 'one', in conflicting ways.
# branches L and R both modify 'two', in conflicting ways.